@@ -46,16 +46,13 @@ import org.slf4j.LoggerFactory;
  * 
  */
 public class OperationMonitorCreator {
-	private static final String SECURITY_EXCEPTION_RIGHTS = "Security exception, you don't have the required rights!";
-	
-	private static Logger logger = LoggerFactory
+	protected static Logger logger = LoggerFactory
 			.getLogger(OperationMonitorCreator.class);
 
-	private static SimpleDateFormat sdf = new SimpleDateFormat(
+	protected static SimpleDateFormat sdf = new SimpleDateFormat(
 			"yyyy-MM-dd HH:mm");
 
-	@SuppressWarnings("unused")
-	private static SimpleDateFormat sdfDate = new SimpleDateFormat(
+	protected static SimpleDateFormat sdfDate = new SimpleDateFormat(
 			"yyyy-MM-dd");
 
 	protected HttpSession session;
@@ -402,7 +399,7 @@ public class OperationMonitorCreator {
 		} catch (SecurityException e) {
 			e.printStackTrace();
 			throw new TDGWTServiceException(
-					SECURITY_EXCEPTION_RIGHTS);
+					"Security exception, you haven't rights!");
 		} catch (Throwable e) {
 			e.printStackTrace();
 			throw new TDGWTServiceException("Error Retrieving Basic Data: "
